[llvm-commits] CVS: llvm/include/llvm/Target/TargetData.h

Chris Lattner lattner at cs.uiuc.edu
Sun Dec 21 23:01:11 PST 2003


Changes in directory llvm/include/llvm/Target:

TargetData.h updated: 1.21 -> 1.22

---
Log message:

Doxygenize methods, add new getIntPtrType method



---
Diffs of the changes:  (+14 -10)

Index: llvm/include/llvm/Target/TargetData.h
diff -u llvm/include/llvm/Target/TargetData.h:1.21 llvm/include/llvm/Target/TargetData.h:1.22
--- llvm/include/llvm/Target/TargetData.h:1.21	Tue Nov 11 16:41:31 2003
+++ llvm/include/llvm/Target/TargetData.h	Sun Dec 21 23:00:45 2003
@@ -71,19 +71,23 @@
   unsigned char getPointerSize()      const { return      PointerSize; }
   AnnotationID  getStructLayoutAID()  const { return AID; }
 
-  // getTypeSize - Return the number of bytes necessary to hold the specified
-  // type
-  uint64_t      getTypeSize     (const Type *Ty) const;
+  /// getTypeSize - Return the number of bytes necessary to hold the specified
+  /// type
+  uint64_t getTypeSize(const Type *Ty) const;
 
-  // getTypeAlignment - Return the minimum required alignment for the specified
-  // type
+  /// getTypeAlignment - Return the minimum required alignment for the specified
+  /// type
   unsigned char getTypeAlignment(const Type *Ty) const;
 
-  // getIndexOffset - return the offset from the beginning of the type for the
-  // specified indices.  This is used to implement getelementptr.
-  //
-  uint64_t      getIndexedOffset(const Type *Ty, 
-				 const std::vector<Value*> &Indices) const;
+  /// getIntPtrType - Return an unsigned integer type that is the same size or
+  /// greater to the host pointer size.
+  const Type *getIntPtrType() const;
+
+  /// getIndexOffset - return the offset from the beginning of the type for the
+  /// specified indices.  This is used to implement getelementptr.
+  ///
+  uint64_t getIndexedOffset(const Type *Ty, 
+                            const std::vector<Value*> &Indices) const;
   
   inline const StructLayout *getStructLayout(const StructType *Ty) const {
     return (const StructLayout*)





More information about the llvm-commits mailing list